{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Apply filters to VCF file",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#main/do_cle_vcf_filter"
                },
                {
                    "type": "float",
                    "id": "#main/filter_mapq0_threshold"
                },
                {
                    "type": "int",
                    "id": "#main/filter_minimum_depth"
                },
                {
                    "type": "float",
                    "id": "#main/filter_somatic_llr_threshold"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_names"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/tumor_bam"
                },
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#filter_vcf_cle.cwl",
                    "in": [
                        {
                            "source": "#main/do_cle_vcf_filter",
                            "id": "#main/filter_vcf_cle/filter"
                        },
                        {
                            "source": "#main/filter_vcf_mapq0/mapq0_filtered_vcf",
                            "id": "#main/filter_vcf_cle/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_cle/cle_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_cle"
                },
                {
                    "run": "#filter_vcf_depth.cwl",
                    "in": [
                        {
                            "source": "#main/filter_minimum_depth",
                            "id": "#main/filter_vcf_depth/minimum_depth"
                        },
                        {
                            "source": "#main/sample_names",
                            "id": "#main/filter_vcf_depth/sample_names"
                        },
                        {
                            "source": "#main/filter_vcf_cle/cle_filtered_vcf",
                            "id": "#main/filter_vcf_depth/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_depth/depth_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_depth"
                },
                {
                    "run": "#filter_vcf_mapq0.cwl",
                    "in": [
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_vcf_mapq0/reference"
                        },
                        {
                            "source": "#main/filter_mapq0_threshold",
                            "id": "#main/filter_vcf_mapq0/threshold"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/filter_vcf_mapq0/tumor_bam"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/filter_vcf_mapq0/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_mapq0/mapq0_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_mapq0"
                },
                {
                    "run": "#filter_vcf_somatic_llr.cwl",
                    "in": [
                        {
                            "source": "#main/filter_somatic_llr_threshold",
                            "id": "#main/filter_vcf_somatic_llr/threshold"
                        },
                        {
                            "source": "#main/filter_vcf_depth/depth_filtered_vcf",
                            "id": "#main/filter_vcf_somatic_llr/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_somatic_llr/somatic_llr_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_somatic_llr"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/filter_vcf_cle/cle_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "cle_annotated_vcf_filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/docm_and_coding_indel_selection.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "filter",
                        "position": 1
                    },
                    "id": "#filter_vcf_cle.cwl/filter"
                },
                {
                    "type": "File",
                    "id": "#filter_vcf_cle.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated_filtered.vcf"
                    },
                    "id": "#filter_vcf_cle.cwl/cle_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_cle.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter variants at sites below a given sequence depth in each sample",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/depth-filter:0.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "/opt/conda/bin/python3",
                "/usr/bin/depth_filter.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)/depth_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minimum_depth",
                        "position": -3
                    },
                    "id": "#filter_vcf_depth.cwl/minimum_depth"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#filter_vcf_depth.cwl/sample_names"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#filter_vcf_depth.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "depth_filtered.vcf"
                    },
                    "id": "#filter_vcf_depth.cwl/depth_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_depth.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter vcf for variants with high percentage of mapq0 reads",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mapq0-filter:v0.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 10000
                }
            ],
            "arguments": [
                "/bin/bash",
                "/usr/bin/mapq0_vcf_filter.sh",
                {
                    "valueFrom": "$(runtime.outdir)/mapq_filtered.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#filter_vcf_mapq0.cwl/reference"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#filter_vcf_mapq0.cwl/threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf_mapq0.cwl/tumor_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#filter_vcf_mapq0.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_filtered.vcf.gz"
                    },
                    "id": "#filter_vcf_mapq0.cwl/mapq0_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_mapq0.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "use the binomial/llr somatic filter to weed out low confidence variants",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/somatic-llr-filter:v0.4.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "/opt/conda/bin/python3",
                "/usr/bin/somatic_llr_filter.py"
            ],
            "arguments": [
                "--overwrite",
                {
                    "valueFrom": "$(runtime.outdir)/somatic_llr_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--llr-threshold",
                        "position": -2
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "somatic_llr_filtered.vcf"
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/somatic_llr_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_somatic_llr.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
